'use client';
'use strict';

var jsxRuntime = require('react/jsx-runtime');
var dom = require('@floating-ui/dom');
var reactSlot = require('@radix-ui/react-slot');
var cl = require('clsx/lite');
var react = require('react');
var useMergeRefs = require('../../utilities/hooks/use-merge-refs/use-merge-refs.js');

/**
 * Tooltip component that displays a small piece of information when hovering or focusing on an element.
 *
 * @example
 * <Tooltip content='This is a tooltip'>
 *  <button>Hover me</button>
 * </Tooltip>
 *
 * @example
 * <Tooltip content='This is a tooltip'>
 *  Hover me
 * </Tooltip>
 */
const Tooltip = react.forwardRef(function Tooltip({ id, children, content, placement = 'top', autoPlacement = true, open, className, ...rest }, ref) {
    const randomTooltipId = react.useId();
    const [internalOpen, setInternalOpen] = react.useState(false);
    const triggerRef = react.useRef(null);
    const tooltipRef = react.useRef(null);
    const mergedRefs = useMergeRefs.useMergeRefs([tooltipRef, ref]);
    const controlledOpen = open ?? internalOpen;
    const setOpen = () => {
        setInternalOpen(true);
    };
    const setClose = () => {
        setInternalOpen(false);
    };
    // Position with floating-ui
    react.useEffect(() => {
        const tooltip = tooltipRef.current;
        const trigger = triggerRef.current;
        tooltip?.togglePopover?.(controlledOpen);
        if (tooltip)
            tooltip.style.opacity = controlledOpen ? '1' : '0';
        if (tooltip && trigger && controlledOpen) {
            return dom.autoUpdate(trigger, tooltip, () => {
                dom.computePosition(trigger, tooltip, {
                    placement,
                    strategy: 'fixed',
                    middleware: [
                        dom.offset((data) => {
                            // get pseudo element arrow size
                            const styles = getComputedStyle(data.elements.floating, '::before');
                            return parseFloat(styles.height);
                        }),
                        ...(autoPlacement
                            ? [dom.flip({ fallbackAxisSideDirection: 'start' }), dom.shift()]
                            : []),
                        dom.shift(),
                        arrowPseudoElement,
                        safeAreaElement,
                    ],
                }).then(({ x, y }) => {
                    tooltip.style.translate = `${x}px ${y}px`;
                });
            });
        }
    }, [controlledOpen, placement]);
    /* Add listener for ESC to dismiss */
    react.useEffect(() => {
        const handleKeyDown = (event) => {
            if (event.key === 'Escape') {
                setInternalOpen(false);
            }
        };
        window.addEventListener('keydown', handleKeyDown);
        return () => {
            window.removeEventListener('keydown', handleKeyDown);
        };
    }, []);
    /* If children is only a string, make a span */
    const ChildContainer = typeof children === 'string' ? 'span' : reactSlot.Slot;
    /* Make sure it is valid */
    if (typeof children !== 'string' && children.type === react.Fragment) {
        console.error('<Tooltip> children needs to be a single ReactElement that can receive a ref and not: <Fragment/> | <></>');
        return null;
    }
    const popoverProps = {
        [react.version.startsWith('19') ? 'popoverTarget' : 'popovertarget']: id ?? randomTooltipId,
        [react.version.startsWith('19')
            ? 'popoverTargetAction'
            : 'popovertargetaction']: 'show',
    };
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx(ChildContainer, { ref: triggerRef, ...popoverProps, onMouseEnter: setOpen, onMouseLeave: setClose, onFocus: setOpen, onBlur: setClose, children: children }), jsxRuntime.jsx("span", { onMouseEnter: setOpen, onMouseLeave: setClose, ref: mergedRefs, role: 'tooltip', className: cl('ds-tooltip', className), id: id ?? randomTooltipId, popover: 'manual', ...rest, children: content })] }));
});
const arrowPseudoElement = {
    name: 'ArrowPseudoElement',
    fn(data) {
        const { elements, rects, placement } = data;
        let arrowX = `${Math.round(rects.reference.width / 2 + rects.reference.x - data.x)}px`;
        let arrowY = `${Math.round(rects.reference.height / 2 + rects.reference.y - data.y)}px`;
        switch (placement) {
            case 'top':
                arrowY = '100%';
                break;
            case 'right':
                arrowX = '0';
                break;
            case 'bottom':
                arrowY = '0';
                break;
            case 'left':
                arrowX = '100%';
                break;
        }
        elements.floating.style.setProperty('--dsc-tooltip-arrow-x', arrowX);
        elements.floating.style.setProperty('--dsc-tooltip-arrow-y', arrowY);
        return data;
    },
};
const safeAreaElement = {
    name: 'SafeAreaElement',
    fn(data) {
        const { elements, placement } = data;
        let width = '100%';
        let height = 'var(--dsc-tooltip-arrow-size)';
        let translate = '0px';
        switch (placement) {
            case 'top':
                translate = `-50% 0%`;
                break;
            case 'right':
                height = '100%';
                width = 'var(--dsc-tooltip-arrow-size)';
                translate = '-100% -50%';
                break;
            case 'bottom':
                translate = '-50% -100%';
                break;
            case 'left':
                height = '100%';
                width = 'var(--dsc-tooltip-arrow-size)';
                translate = '0 -50%';
                break;
        }
        elements.floating.style.setProperty('--_dsc-tooltip-safearea-height', height);
        elements.floating.style.setProperty('--_dsc-tooltip-safearea-width', width);
        elements.floating.style.setProperty('--_dsc-tooltip-safearea-translate', translate);
        return data;
    },
};

exports.Tooltip = Tooltip;
